Installation
------------

The usual method should be adequate one of::

    % pip install amqpctl
    % easy_install amqpctl

If you are interested in the development branch of the code, or to contribute
any patches or whatnot, the mercurial repository is
http://bitbucket.org/ww/amqpctl . A convenient way of installing for development
is to do::

   % pip install -e hg+http://bitbucket.org/ww/amqpctl#egg=amqpctl

In any event, having done one of the above, there should now be 
a command :program:`amqpctl` that is installed and runnable.